@@ -181,6 +181,9 @@ class OctoBot:
         exchange_managers = [
             trading_api.get_exchange_manager_from_exchange_id(exchange_manager_id)
             for exchange_manager_id in self.exchange_producer.exchange_manager_ids
+            if trading_api.is_trader_existing_and_enabled(
+                trading_api.get_exchange_manager_from_exchange_id(exchange_manager_id)
+            )
         ]
         # start automations now that everything started
         await self.automation.initialize()
@@ -189,10 +192,13 @@ class OctoBot:
         except asyncio.TimeoutError:
             pass
         try:
-            await storage.clear_run_metadata(self.bot_id)
-            await storage.store_run_metadata(self.bot_id, exchange_managers, self.start_time)
+            if exchange_managers:
+                await storage.clear_run_metadata(self.bot_id)
+                await storage.store_run_metadata(self.bot_id, exchange_managers, self.start_time)
+            else:
+                self.logger.debug("Skipping run metadata update: no available exchange manager")
         except Exception as err:
-            self.logger.exception(err, True, f"Error when storing live matadata: {err}")
+            self.logger.exception(err, True, f"Error when storing live metadata: {err}")
 
     async def stop(self):
         try:
@@ -206,7 +212,7 @@ class OctoBot:
             await self.service_feed_producer.stop()
             await os_clock_sync.stop_clock_synchronizer()
             await system_resources_watcher.stop_system_resources_watcher()
-            service_api.stop_services()
+            await service_api.stop_services()
             await self.interface_producer.stop()
             await databases.close_bot_storage(self.bot_id)
             if self.automation is not None:
@@ -236,8 +242,9 @@ class OctoBot:
 
     def _log_config(self):
         exchanges = [
-            f"{exchange}[{config.get(commons_constants.CONFIG_EXCHANGE_TYPE, commons_constants.CONFIG_EXCHANGE_SPOT)}]"
-            for exchange, config in self.config[commons_constants.CONFIG_EXCHANGES].items()
+            f"{exchange}" \
+            f"[{config.get(commons_constants.CONFIG_EXCHANGE_TYPE, trading_api.get_default_exchange_type(exchange))}]"
+            for exchange, config in self.config.get(commons_constants.CONFIG_EXCHANGES, {}).items()
             if config.get(commons_constants.CONFIG_ENABLED_OPTION, True)
         ]
         has_real_trader = trading_api.is_trader_enabled_in_config(self.config)
@@ -245,7 +252,8 @@ class OctoBot:
         trader_str = "real trader" if has_real_trader else "simulated trader" if has_simulated_trader else "no trader"
         traded_symbols = trading_api.get_config_symbols(self.config, True)
         symbols_str = ', '.join(set(traded_symbols))
-        self.logger.info(f"Starting OctoBot with {trader_str} on {', '.join(exchanges)} "
+        self.logger.info(f"Starting OctoBot with {trader_str} on "
+                         f"{', '.join(exchanges) if exchanges else 'no exchange'} "
                          f"trading {symbols_str or 'nothing'} and using bot_id: {self.bot_id}")
 
     def get_edited_config(self, config_key, dict_only=True):
